=======
History
=======

0.1.2 (2016-11-10)
------------------
* Ensure compatibility with Python 3.3 and 3.4.
* Add a “pysrc3” wrapper script.
* Upgrade dev dependencies.
* Fix Flake8 warnings.

0.1.1 (2016-11-10)
------------------

* First release on PyPI.
